@@ -50,8 +50,13 @@ class FileProtocolHandler:
 
         return path if exists else None
 
+    def get_modified_time( self, url: urllib.parse.ParseResult) -> datetime:
+        """ Return the modified date time of the project referenced by its url
+        """
+        path = self._check_file(Path(url.path))
+        return datetime.fromtimestamp(path.stat().st_mtime)
 
-    def get_project( self, url: Optional[urllib.parse.ParseResult], strict: Optional[bool]=None,
+    def get_project( self, url: Optional[urllib.parse.ParseResult],
                      project: Optional[QgsProject]=None,
                      timestamp: Optional[datetime]=None) -> Tuple[QgsProject, datetime]:
         """ Create or return a proect
@@ -70,7 +75,7 @@ class FileProtocolHandler:
         modified_time = datetime.fromtimestamp(path.stat().st_mtime)
         if timestamp is None or timestamp < modified_time:
             cachmngr  = componentmanager.get_service('@3liz.org/cache-manager;1')
-            project   = cachmngr.read_project(str(path), strict=strict)
+            project   = cachmngr.read_project(str(path))
             timestamp = modified_time
 
         return project, timestamp
